<?php
namespace Teknisa\ACL\Util;

use Teknisa\ACL\Repositories\AccessProfile;
use Teknisa\Libs\Util\Environment as LibEnvironment;
use Zeedhi\ZhuAcl\Util\Environment as ZeedhiEnvironment;

class AclEnvironment extends LibEnvironment implements ZeedhiEnvironment {

    protected $projectId;
    protected $session;
    /** @var AccessProfile $accessProfileRepository */
    protected $accessProfileRepository;
    protected $defaultRule = "I";

    const ACTIVE_RULE = 'A';

    public function __construct($session, $projectId, AccessProfile $accessProfileRepository) {
        $this->session   = $session;
        $this->projectId = $projectId;
        $this->accessProfileRepository = $accessProfileRepository;
    }

    public function getUserId(){
        return $this->getCurrentUserId();
    }

    public function getOrganizationId(){
        return $this->getCurrentOrganizationId();
    }
    
    public function getIdUtlPerfilFilial(){
        return $this->getIdUtlPerfilFilial();
    }

    public function getCurrentTime(){
        return new \DateTime();
    }

    public function getProjectId(){
        return $this->projectId;
    }

    public function getJsonsDirectories(){
        return array();
    }

    public function getDefaultRule() {
        $accessProfile = $this->session->get('ACCESS_PROFILE');
        $defaultRuleParameter = AclUtilities::getDefaultRuleParameter();

        if($defaultRuleParameter) {
            $defaultRule = $defaultRuleParameter;
        } else if(empty($accessProfile)) {
            $defaultRule = $this->defaultRule;
        } else {
            $generalParams = $this->accessProfileRepository->findAccessControllUtilization($this->getCurrentOrganizationId());
            if(empty($generalParams) ||
                isset($generalParams[0]['IDUTCTRLACESWEB']) && $generalParams[0]['IDUTCTRLACESWEB'] == 'N') {
                $defaultRule = self::ACTIVE_RULE;
            } else {
                $defaultRule = $this->defaultRule;
            }
        }

        return $defaultRule;
    }
}